Module capability

Module capability 

CAPABILITY message type implementation

The CAPABILITY message type is used to notify the receiver about the types of messages supported by the sender.

Structs

CapabilityMessage
CAPABILITY message containing list of supported message types