Module qtdata

Module qtdata 

QTDATA (QuaternionTrackingData) message type implementation

The QTDATA message type is used to transfer 3D positions and orientations of surgical tools, markers, etc. using quaternions for orientation.

Structs

QtDataMessage
QTDATA message containing multiple tracking elements
TrackingElement
Tracking data element with name, type, position and quaternion

Enums

InstrumentType
Instrument type