CAPABILITY message type implementation
The CAPABILITY message type is used to notify the receiver about the types of messages supported by the sender.
Structs
- Capability
Message - CAPABILITY message containing list of supported message types