QTDATA (QuaternionTrackingData) message type implementation
The QTDATA message type is used to transfer 3D positions and orientations of surgical tools, markers, etc. using quaternions for orientation.
Structs
- QtData
Message - QTDATA message containing multiple tracking elements
- Tracking
Element - Tracking data element with name, type, position and quaternion
Enums
- Instrument
Type - Instrument type